TimeZoneInfo

Struct TimeZoneInfo 

pub struct TimeZoneInfo {
    pub id: Option<TimeZoneId>,
    pub total_offset_at_time: Option<i64>,
    pub in_dst_at_time: Option<bool>,
    /* private fields */
}
Describes a Time Zone’s properties at a particular moment in time.

TODO(https://fxbug.dev/42162409): Additional fields with a breakdown of offsets and DST status.

Fields

id: Option<TimeZoneId>

The time zone’s IANA ID.

total_offset_at_time: Option<i64>

The total offset (including Daylight Savings, if the time zone is in Daylight Savings Time) from UTC at the queried time (at_time). If the time zone is ahead of UTC, this will be a positive value; if behind UTC, a negative value.

in_dst_at_time: Option<bool>

Indicates whether the time zone is in Daylight Savings Time at the queried time (at_time).